mirror of
https://github.com/encounter/rust-sdl2.git
synced 2026-07-10 21:18:41 -07:00
52 lines
33 KiB
HTML
52 lines
33 KiB
HTML
|
|
<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="API documentation for the Rust `__darwin_x86_float_state64` struct in crate `libc`."><meta name="keywords" content="rust, rustlang, rust-lang, __darwin_x86_float_state64"><title>libc::__darwin_x86_float_state64 - Rust</title><link rel="stylesheet" type="text/css" href="../normalize.css"><link rel="stylesheet" type="text/css" href="../rustdoc.css" id="mainThemeStyle"><link rel="stylesheet" type="text/css" href="../dark.css"><link rel="stylesheet" type="text/css" href="../light.css" id="themeStyle"><script src="../storage.js"></script><noscript><link rel="stylesheet" href="../noscript.css"></noscript><link rel="shortcut icon" href="../favicon.ico"><style type="text/css">#crate-search{background-image:url("../down-arrow.svg");}</style></head><body class="rustdoc struct"><!--[if lte IE 8]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="sidebar"><div class="sidebar-menu">☰</div><a href='../libc/index.html'><div class='logo-container'><img src='../rust-logo.png' alt='logo'></div></a><p class='location'>Struct __darwin_x86_float_state64</p><div class="sidebar-elems"><div class="block items"><a class="sidebar-title" href="#fields">Fields</a><div class="sidebar-links"><a href="#structfield.__fpu_reserved">__fpu_reserved</a><a href="#structfield.__fpu_ftw">__fpu_ftw</a><a href="#structfield.__fpu_rsrv1">__fpu_rsrv1</a><a href="#structfield.__fpu_fop">__fpu_fop</a><a href="#structfield.__fpu_ip">__fpu_ip</a><a href="#structfield.__fpu_cs">__fpu_cs</a><a href="#structfield.__fpu_rsrv2">__fpu_rsrv2</a><a href="#structfield.__fpu_dp">__fpu_dp</a><a href="#structfield.__fpu_ds">__fpu_ds</a><a href="#structfield.__fpu_rsrv3">__fpu_rsrv3</a><a href="#structfield.__fpu_mxcsr">__fpu_mxcsr</a><a href="#structfield.__fpu_mxcsrmask">__fpu_mxcsrmask</a><a href="#structfield.__fpu_stmm0">__fpu_stmm0</a><a href="#structfield.__fpu_stmm1">__fpu_stmm1</a><a href="#structfield.__fpu_stmm2">__fpu_stmm2</a><a href="#structfield.__fpu_stmm3">__fpu_stmm3</a><a href="#structfield.__fpu_stmm4">__fpu_stmm4</a><a href="#structfield.__fpu_stmm5">__fpu_stmm5</a><a href="#structfield.__fpu_stmm6">__fpu_stmm6</a><a href="#structfield.__fpu_stmm7">__fpu_stmm7</a><a href="#structfield.__fpu_xmm0">__fpu_xmm0</a><a href="#structfield.__fpu_xmm1">__fpu_xmm1</a><a href="#structfield.__fpu_xmm2">__fpu_xmm2</a><a href="#structfield.__fpu_xmm3">__fpu_xmm3</a><a href="#structfield.__fpu_xmm4">__fpu_xmm4</a><a href="#structfield.__fpu_xmm5">__fpu_xmm5</a><a href="#structfield.__fpu_xmm6">__fpu_xmm6</a><a href="#structfield.__fpu_xmm7">__fpu_xmm7</a><a href="#structfield.__fpu_xmm8">__fpu_xmm8</a><a href="#structfield.__fpu_xmm9">__fpu_xmm9</a><a href="#structfield.__fpu_xmm10">__fpu_xmm10</a><a href="#structfield.__fpu_xmm11">__fpu_xmm11</a><a href="#structfield.__fpu_xmm12">__fpu_xmm12</a><a href="#structfield.__fpu_xmm13">__fpu_xmm13</a><a href="#structfield.__fpu_xmm14">__fpu_xmm14</a><a href="#structfield.__fpu_xmm15">__fpu_xmm15</a><a href="#structfield.__fpu_reserved1">__fpu_reserved1</a></div><a class="sidebar-title" href="#implementations">Trait Implementations</a><div class="sidebar-links"><a href="#impl-Clone">Clone</a><a href="#impl-Copy">Copy</a></div><a class="sidebar-title" href="#synthetic-implementations">Auto Trait Implementations</a><div class="sidebar-links"><a href="#impl-Send">Send</a><a href="#impl-Sync">Sync</a><a href="#impl-Unpin">Unpin</a></div><a class="sidebar-title" href="#blanket-implementations">Blanket Implementations</a><div class="sidebar-links"><a href="#impl-Any">Any</a><a href="#impl-Borrow%3CT%3E">Borrow<T></a><a href="#impl-BorrowMut%3CT%3E">BorrowMut<T></a><a href="#impl-From%3CT%3E">From<T></a><a href="#impl-Into%3CU%3E">Into<U></a><a href="#impl-TryFrom%3CU%3E">TryFrom<U></a><a href="#impl-TryInto%3CU%3E">TryInto<U
|
||
|
|
pub __fpu_reserved: [<a class="type" href="../libc/type.c_int.html" title="type libc::c_int">c_int</a>; 2],
|
||
|
|
pub __fpu_ftw: u8,
|
||
|
|
pub __fpu_rsrv1: u8,
|
||
|
|
pub __fpu_fop: u16,
|
||
|
|
pub __fpu_ip: u32,
|
||
|
|
pub __fpu_cs: u16,
|
||
|
|
pub __fpu_rsrv2: u16,
|
||
|
|
pub __fpu_dp: u32,
|
||
|
|
pub __fpu_ds: u16,
|
||
|
|
pub __fpu_rsrv3: u16,
|
||
|
|
pub __fpu_mxcsr: u32,
|
||
|
|
pub __fpu_mxcsrmask: u32,
|
||
|
|
pub __fpu_stmm0: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_stmm1: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_stmm2: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_stmm3: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_stmm4: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_stmm5: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_stmm6: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_stmm7: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a>,
|
||
|
|
pub __fpu_xmm0: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm1: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm2: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm3: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm4: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm5: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm6: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm7: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm8: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm9: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm10: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm11: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm12: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm13: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm14: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_xmm15: <a class="struct" href="../libc/struct.__darwin_xmm_reg.html" title="struct libc::__darwin_xmm_reg">__darwin_xmm_reg</a>,
|
||
|
|
pub __fpu_reserved1: <a class="type" href="../libc/type.c_int.html" title="type libc::c_int">c_int</a>,
|
||
|
|
// some fields omitted
|
||
|
|
}</pre></div><h2 id='fields' class='fields small-section-header'>
|
||
|
|
Fields<a href='#fields' class='anchor'></a></h2><span id="structfield.__fpu_reserved" class="structfield small-section-header"><a href="#structfield.__fpu_reserved" class="anchor field"></a><code id="__fpu_reserved.v">__fpu_reserved: [<a class="type" href="../libc/type.c_int.html" title="type libc::c_int">c_int</a>; 2]</code></span><span id="structfield.__fpu_ftw" class="structfield small-section-header"><a href="#structfield.__fpu_ftw" class="anchor field"></a><code id="__fpu_ftw.v">__fpu_ftw: u8</code></span><span id="structfield.__fpu_rsrv1" class="structfield small-section-header"><a href="#structfield.__fpu_rsrv1" class="anchor field"></a><code id="__fpu_rsrv1.v">__fpu_rsrv1: u8</code></span><span id="structfield.__fpu_fop" class="structfield small-section-header"><a href="#structfield.__fpu_fop" class="anchor field"></a><code id="__fpu_fop.v">__fpu_fop: u16</code></span><span id="structfield.__fpu_ip" class="structfield small-section-header"><a href="#structfield.__fpu_ip" class="anchor field"></a><code id="__fpu_ip.v">__fpu_ip: u32</code></span><span id="structfield.__fpu_cs" class="structfield small-section-header"><a href="#structfield.__fpu_cs" class="anchor field"></a><code id="__fpu_cs.v">__fpu_cs: u16</code></span><span id="structfield.__fpu_rsrv2" class="structfield small-section-header"><a href="#structfield.__fpu_rsrv2" class="anchor field"></a><code id="__fpu_rsrv2.v">__fpu_rsrv2: u16</code></span><span id="structfield.__fpu_dp" class="structfield small-section-header"><a href="#structfield.__fpu_dp" class="anchor field"></a><code id="__fpu_dp.v">__fpu_dp: u32</code></span><span id="structfield.__fpu_ds" class="structfield small-section-header"><a href="#structfield.__fpu_ds" class="anchor field"></a><code id="__fpu_ds.v">__fpu_ds: u16</code></span><span id="structfield.__fpu_rsrv3" class="structfield small-section-header"><a href="#structfield.__fpu_rsrv3" class="anchor field"></a><code id="__fpu_rsrv3.v">__fpu_rsrv3: u16</code></span><span id="structfield.__fpu_mxcsr" class="structfield small-section-header"><a href="#structfield.__fpu_mxcsr" class="anchor field"></a><code id="__fpu_mxcsr.v">__fpu_mxcsr: u32</code></span><span id="structfield.__fpu_mxcsrmask" class="structfield small-section-header"><a href="#structfield.__fpu_mxcsrmask" class="anchor field"></a><code id="__fpu_mxcsrmask.v">__fpu_mxcsrmask: u32</code></span><span id="structfield.__fpu_stmm0" class="structfield small-section-header"><a href="#structfield.__fpu_stmm0" class="anchor field"></a><code id="__fpu_stmm0.v">__fpu_stmm0: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a></code></span><span id="structfield.__fpu_stmm1" class="structfield small-section-header"><a href="#structfield.__fpu_stmm1" class="anchor field"></a><code id="__fpu_stmm1.v">__fpu_stmm1: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a></code></span><span id="structfield.__fpu_stmm2" class="structfield small-section-header"><a href="#structfield.__fpu_stmm2" class="anchor field"></a><code id="__fpu_stmm2.v">__fpu_stmm2: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a></code></span><span id="structfield.__fpu_stmm3" class="structfield small-section-header"><a href="#structfield.__fpu_stmm3" class="anchor field"></a><code id="__fpu_stmm3.v">__fpu_stmm3: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a></code></span><span id="structfield.__fpu_stmm4" class="structfield small-section-header"><a href="#structfield.__fpu_stmm4" class="anchor field"></a><code id="__fpu_stmm4.v">__fpu_stmm4: <a class="struct" href="../libc/struct.__darwin_mmst_reg.html" title="struct libc::__darwin_mmst_reg">__darwin_mmst_reg</a></code></span><span id="structfield.__fpu_stmm5" class="structfield small-section-header"><a href="#structfield.__fpu_stmm5" class="anchor field">
|
||
|
|
</div><h4 id='method.clone_from' class="method hidden"><code id='clone_from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from' class='fnname'>clone_from</a>(&mut self, source: &Self)</code><span class='since' title='Stable since Rust version 1.0.0'>1.0.0</span><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/clone.rs.html#131-133' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs copy-assignment from <code>source</code>. <a href="https://doc.rust-lang.org/nightly/core/clone/trait.Clone.html#method.clone_from">Read more</a></p>
|
||
|
|
</div></div><h3 id='impl-Copy' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Copy.html" title="trait core::marker::Copy">Copy</a> for <a class="struct" href="../libc/struct.__darwin_x86_float_state64.html" title="struct libc::__darwin_x86_float_state64">__darwin_x86_float_state64</a></code><a href='#impl-Copy' class='anchor'></a><a class='srclink' href='../src/libc/macros.rs.html#82' title='goto source code'>[src]</a></h3><div class='impl-items'></div></div><h2 id='synthetic-implementations' class='small-section-header'>Auto Trait Implementations<a href='#synthetic-implementations' class='anchor'></a></h2><div id='synthetic-implementations-list'><h3 id='impl-Send' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Send.html" title="trait core::marker::Send">Send</a> for <a class="struct" href="../libc/struct.__darwin_x86_float_state64.html" title="struct libc::__darwin_x86_float_state64">__darwin_x86_float_state64</a></code><a href='#impl-Send' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Sync' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sync.html" title="trait core::marker::Sync">Sync</a> for <a class="struct" href="../libc/struct.__darwin_x86_float_state64.html" title="struct libc::__darwin_x86_float_state64">__darwin_x86_float_state64</a></code><a href='#impl-Sync' class='anchor'></a></h3><div class='impl-items'></div><h3 id='impl-Unpin' class='impl'><code class='in-band'>impl <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Unpin.html" title="trait core::marker::Unpin">Unpin</a> for <a class="struct" href="../libc/struct.__darwin_x86_float_state64.html" title="struct libc::__darwin_x86_float_state64">__darwin_x86_float_state64</a></code><a href='#impl-Unpin' class='anchor'></a></h3><div class='impl-items'></div></div><h2 id='blanket-implementations' class='small-section-header'>Blanket Implementations<a href='#blanket-implementations' class='anchor'></a></h2><div id='blanket-implementations-list'><h3 id='impl-Any' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html" title="trait core::any::Any">Any</a> for T <span class="where fmt-newline">where<br> T: 'static + ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>, </span></code><a href='#impl-Any' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#108-112' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.type_id' class="method hidden"><code id='type_id.v'>fn <a href='https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id' class='fnname'>type_id</a>(&self) -> <a class="struct" href="https://doc.rust-lang.org/nightly/core/any/struct.TypeId.html" title="struct core::any::TypeId">TypeId</a></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/any.rs.html#109-111' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Gets the <code>TypeId</code> of <code>self</code>. <a href="https://doc.rust-lang.org/nightly/core/any/trait.Any.html#tymethod.type_id">Read more</a></p>
|
||
|
|
</div></div><h3 id='impl-Borrow%3CT%3E' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html" title="trait core::borrow::Borrow">Borrow</a><T> for T <span class="where fmt-newline">where<br> T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>, </span></code><a href='#impl-Borrow%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#213-217' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow' class="method hidden"><code id='borrow.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow' class='fnname'>borrow</a>(&self) -> &T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#214-216' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Immutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.Borrow.html#tymethod.borrow">Read more</a></p>
|
||
|
|
</div></div><h3 id='impl-BorrowMut%3CT%3E' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html" title="trait core::borrow::BorrowMut">BorrowMut</a><T> for T <span class="where fmt-newline">where<br> T: ?<a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a>, </span></code><a href='#impl-BorrowMut%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#220-224' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.borrow_mut' class="method hidden"><code id='borrow_mut.v'>fn <a href='https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut' class='fnname'>borrow_mut</a>(&mut self) -> &mut T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/borrow.rs.html#221-223' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Mutably borrows from an owned value. <a href="https://doc.rust-lang.org/nightly/core/borrow/trait.BorrowMut.html#tymethod.borrow_mut">Read more</a></p>
|
||
|
|
</div></div><h3 id='impl-From%3CT%3E' class='impl'><code class='in-band'>impl<T> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a><T> for T</code><a href='#impl-From%3CT%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#565-569' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.from' class="method hidden"><code id='from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.From.html#tymethod.from' class='fnname'>from</a>(t: T) -> T</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#566-568' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
||
|
|
</div></div><h3 id='impl-Into%3CU%3E' class='impl'><code class='in-band'>impl<T, U> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><U> for T <span class="where fmt-newline">where<br> U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.From.html" title="trait core::convert::From">From</a><T>, </span></code><a href='#impl-Into%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#554-561' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='method.into' class="method hidden"><code id='into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.Into.html#tymethod.into' class='fnname'>into</a>(self) -> U</code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#558-560' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
||
|
|
</div></div><h3 id='impl-TryFrom%3CU%3E' class='impl'><code class='in-band'>impl<T, U> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><U> for T <span class="where fmt-newline">where<br> U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.Into.html" title="trait core::convert::Into">Into</a><T>, </span></code><a href='#impl-TryFrom%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#602-611' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error' class="type"><code id='Error.t'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error' class="type">Error</a> = <a class="enum" href="https://doc.rust-lang.org/nightly/core/convert/enum.Infallible.html" title="enum core::convert::Infallible">Infallible</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
|
||
|
|
</div><h4 id='method.try_from' class="method hidden"><code id='try_from.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#tymethod.try_from' class='fnname'>try_from</a>(value: U) -> <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a><T, <T as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><U>>::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#608-610' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
||
|
|
</div></div><h3 id='impl-TryInto%3CU%3E' class='impl'><code class='in-band'>impl<T, U> <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html" title="trait core::convert::TryInto">TryInto</a><U> for T <span class="where fmt-newline">where<br> U: <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>, </span></code><a href='#impl-TryInto%3CU%3E' class='anchor'></a><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#588-597' title='goto source code'>[src]</a></h3><div class='impl-items'><h4 id='associatedtype.Error-1' class="type"><code id='Error.t-1'>type <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#associatedtype.Error' class="type">Error</a> = <U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>>::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a></code></h4><div class='docblock'><p>The type returned in the event of a conversion error.</p>
|
||
|
|
</div><h4 id='method.try_into' class="method hidden"><code id='try_into.v'>fn <a href='https://doc.rust-lang.org/nightly/core/convert/trait.TryInto.html#tymethod.try_into' class='fnname'>try_into</a>(self) -> <a class="enum" href="https://doc.rust-lang.org/nightly/core/result/enum.Result.html" title="enum core::result::Result">Result</a><U, <U as <a class="trait" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html" title="trait core::convert::TryFrom">TryFrom</a><T>>::<a class="type" href="https://doc.rust-lang.org/nightly/core/convert/trait.TryFrom.html#associatedtype.Error" title="type core::convert::TryFrom::Error">Error</a>></code><a class='srclink' href='https://doc.rust-lang.org/nightly/src/core/convert/mod.rs.html#594-596' title='goto source code'>[src]</a></h4><div class='docblock hidden'><p>Performs the conversion.</p>
|
||
|
|
</div></div></div></section><section id="search" class="content hidden"></section><section class="footer"></section><script>window.rootPath = "../";window.currentCrate = "libc";</script><script src="../aliases.js"></script><script src="../main.js"></script><script defer src="../search-index.js"></script></body></html>
|